@@ -7,7 +7,7 @@
 #include <sys/stat.h>
 #include <sys/time.h>
 
-__ID("@(#) $Id: cpuid.cc 1959 2008-05-09 20:32:50Z lyonel $");
+__ID("@(#) $Id: cpuid.cc 2069 2009-02-12 22:53:09Z lyonel $");
 
 #if defined(__i386__) || defined(__alpha__)
 
@@ -646,7 +646,7 @@ bool scan_cpuid(hwNode & n)
 
     cpu->claim(true);                             // claim the cpu and all its children
     if (cpu->getSize() == 0)
-      cpu->setSize((long long) (1000000 * round_MHz(average_MHz(currentcpu))));
+      cpu->setSize((unsigned long long) (1000000uL * round_MHz(average_MHz(currentcpu))));
 
     currentcpu++;
   }
