@@ -88,7 +88,7 @@
 #include <stdlib.h>
 #include <sys/mman.h>
 
-__ID("@(#) $Id: dmi.cc 1959 2008-05-09 20:32:50Z lyonel $");
+__ID("@(#) $Id: dmi.cc 2069 2009-02-12 22:53:09Z lyonel $");
 
 static int currentcpu = 0;
 
@@ -462,9 +462,9 @@ u8 cachetype = 0)
 }
 
 
-static char *dmi_memory_array_location(u8 num)
+static const char *dmi_memory_array_location(u8 num)
 {
-  static char *memory_array_location[] =
+  static const char *memory_array_location[] =
   {
     "",                                           /* 0x00 */
     "",
@@ -478,7 +478,7 @@ static char *dmi_memory_array_location(u8 num)
     "Proprietary add-on card",
     "NuBus",                                      /* 0x0A , master.mif says 16 */
   };
-  static char *jp_memory_array_location[] =
+  static const char *jp_memory_array_location[] =
   {
     "PC-98/C20 add-on card",                      /* 0xA0 */
     "PC-98/C24 add-on card",
@@ -494,9 +494,9 @@ static char *dmi_memory_array_location(u8 num)
 }
 
 
-static char *dmi_memory_device_form_factor(u8 num)
+static const char *dmi_memory_device_form_factor(u8 num)
 {
-  static char *memory_device_form_factor[] =
+  static const char *memory_device_form_factor[] =
   {
     "",
     "",
@@ -513,16 +513,17 @@ static char *dmi_memory_device_form_factor(u8 num)
     " RIMM",
     " SODIMM",
     " SRIMM",
+    " FB-DIMM",
   };
-  if (num > 0x0E)
+  if (num > 0x0F)
     return "";
   return memory_device_form_factor[num];
 }
 
 
-static char *dmi_memory_device_type(u8 num)
+static const char *dmi_memory_device_type(u8 num)
 {
-  static char *memory_device_type[] =
+  static const char *memory_device_type[] =
   {
     "",                                           /* 0x00 */
     "",
@@ -543,8 +544,10 @@ static char *dmi_memory_device_type(u8 num)
     " SGRAM",
     " RDRAM",
     " DDR",                                       /* 0x12 */
+    " DDR2",                                      /* 0x13 */
+    " DDR2 FB-DIMM",                              /* 0x14 */
   };
-  if (num > 0x12)
+  if (num > 0x14)
     return "";
   return memory_device_type[num];
 }
@@ -1021,7 +1024,8 @@ int dmiversionmin)
             hardwarenode->setProduct(dmi_string(dm, data[5]));
             hardwarenode->setVersion(dmi_string(dm, data[6]));
             hardwarenode->setSerial(dmi_string(dm, data[7]));
-            hardwarenode->setSlot(dmi_string(dm, data[0x0A]));
+            if(dm->length >= 0x0a)
+              hardwarenode->setSlot(dmi_string(dm, data[0x0A]));
             hardwarenode->setHandle(handle);
             hardwarenode->setDescription("Motherboard");
             hardwarenode->addHint("icon", string("motherboard"));
@@ -1099,23 +1103,33 @@ int dmiversionmin)
                 string(dmi_string(dm, data[0x22])) + ")");
           }
 
-// external clock
-          u = data[0x13] << 8 | data[0x12];
-          newnode.setClock(u * 1000000);
-// maximum speed
-          u = data[0x15] << 8 | data[0x14];
-          newnode.setCapacity(u * 1000000);
-// current speed
-          u = data[0x17] << 8 | data[0x16];
-          newnode.setSize(u * 1000000);
+// CPU socket populated ?
+          if (data[0x18] & 0x40)
+          {
+	// external clock
+          	u = data[0x13] << 8 | data[0x12];
+          	newnode.setClock(u * 1000000);
+	// maximum speed
+          	u = data[0x15] << 8 | data[0x14];
+          	newnode.setCapacity(u * 1000000);
+	// current speed
+          	u = data[0x17] << 8 | data[0x16];
+          	newnode.setSize(u * 1000000);
 
-          if (newnode.getCapacity() < newnode.getSize())
-            newnode.setCapacity(0);
+          	if (newnode.getCapacity() < newnode.getSize())
+            	newnode.setCapacity(0);
 
-// CPU enabled/disabled by BIOS?
-          u = data[0x18] & 0x07;
-          if ((u == 2) || (u == 3) || (u == 4))
+	// CPU enabled/disabled by BIOS?
+          	u = data[0x18] & 0x07;
+          	if ((u == 2) || (u == 3) || (u == 4))
+            	newnode.disable();
+          }
+          else
+          {
+            newnode.setBusInfo("");	// blank businfo to make sure further detections can't confuse this empty CPU slot with a real CPU
+            newnode.setDescription(newnode.getDescription() + " [empty]");
             newnode.disable();
+          }
 
           newnode.setHandle(handle);
 
@@ -1244,9 +1258,8 @@ int dmiversionmin)
           newnode.setHandle(handle);
           newnode.setPhysId(dm->handle);
           newnode.claim();
-          if(newnode.getSize()==0)
-            newnode.disable();
-          hardwarenode->addChild(newnode);
+          if(newnode.getSize()!=0)
+            hardwarenode->addChild(newnode);
         }
         break;
       case 8:
@@ -1585,6 +1598,17 @@ int dmiversionmin)
         break;
       case 30:
 // Out-of-Band Remote Access
+        if (dm->length < 0x06)
+          break;
+        else
+        {
+          hwNode oob("remoteaccess", hw::system);
+
+          oob.setVendor(dmi_string(dm, data[0x04]));
+          if(data[0x05] & 0x2) oob.addCapability("outbound", "make outbound connections");
+          if(data[0x05] & 0x1) oob.addCapability("inbound", "receive inbound connections");
+          node.addChild(oob);
+        }
         break;
       case 31:
 // Boot Integrity Services Entry Point
@@ -1615,6 +1639,20 @@ int dmiversionmin)
         break;
       case 39:
 // Power Supply
+        if (dm->length < 0x15)
+          break;
+        else
+        {
+          hwNode power("power", hw::power);
+
+          power.setDescription(dmi_string(dm, data[0x06]));
+          power.setVendor(dmi_string(dm, data[0x07]));
+          power.setSerial(dmi_string(dm, data[0x08]));
+          power.setProduct(dmi_string(dm, data[0x0a]));
+          power.setVersion(dmi_string(dm, data[0x0b]));
+          power.setCapacity(data[0x0c] + 256*data[0x0d]);
+          node.addChild(power);
+        }
         break;
       case 126:
 // Inactive
@@ -1669,6 +1707,11 @@ bool scan_dmi(hwNode & n)
   u8 smmajver = 0, smminver = 0;
   u16 dmimaj = 0, dmimin = 0;
   currentcpu = 0;
+
+#ifdef __hppa__
+  return false;		// SMBIOS not supported on PA-RISC machines
+#endif
+
   if (sizeof(u8) != 1 || sizeof(u16) != 2 || sizeof(u32) != 4)
 // compiler incompatibility
     return false;
