@@ -19,7 +19,7 @@
 
 using namespace hw;
 
-__ID("@(#) $Id: hw.cc 1959 2008-05-09 20:32:50Z lyonel $");
+__ID("@(#) $Id: hw.cc 2069 2009-02-12 22:53:09Z lyonel $");
 
 struct hwNode_i
 {
@@ -886,6 +886,20 @@ string hwNode::getCapabilities() const
 }
 
 
+vector < string > hwNode::getCapabilitiesList() const
+{
+  vector < string > result;
+
+  if (!This)
+    return result;
+
+  for (unsigned int i = 0; i < This->features.size(); i++)
+    result.push_back(This->features[i]);
+
+  return result;
+}
+
+
 string hwNode::getCapabilityDescription(const string & feature) const
 {
   string featureid = cleanupId(feature);
@@ -1310,17 +1324,17 @@ string hwNode::asXML(unsigned level)
     out << "<?xml version=\"1.0\" standalone=\"yes\" ?>" << endl;
     out << "<!-- generated by lshw-" << getpackageversion() << " -->" <<
   #if defined(__GNUC__) && defined(__VERSION__)
-      endl << "<!-- GCC " << __VERSION__ << " -->" <<
+      endl << "<!-- GCC " << escapecomment(__VERSION__) << " -->" <<
   #endif
       endl;
 
     if(uname(&un) == 0)
-      out << "<!-- " << un.sysname << " " << un.release << " " << un.version << " " << un.machine << " -->" << endl;
+      out << "<!-- " << escapecomment(un.sysname) << " " << escapecomment(un.release) << " " << escapecomment(un.version) << " " << escapecomment(un.machine) << " -->" << endl;
   #if defined(__GLIBC__)
     char version[PATH_MAX];
 
       if(confstr(_CS_GNU_LIBC_VERSION, version, sizeof(version))>0)
-        out << "<!-- GNU libc " << __GLIBC__ << " (" << version << ") -->" << endl;
+        out << "<!-- GNU libc " << __GLIBC__ << " (" << escapecomment(version) << ") -->" << endl;
   #endif
     if (geteuid() != 0)
       out << "<!-- WARNING: not running as root -->" << endl;
@@ -1631,6 +1645,7 @@ struct hw::resource_i
   unsigned int ui1;
   unsigned long ul1, ul2;
   unsigned long long ull1, ull2;
+  bool b;
 
   int refcount;
 };
@@ -1732,7 +1747,7 @@ unsigned long end)
 
 
 resource resource::mem(unsigned long long start,
-unsigned long long end)
+unsigned long long end, bool prefetchable)
 {
   resource r;
 
@@ -1742,6 +1757,7 @@ unsigned long long end)
   r.This->type = hw::mem;
   r.This->ull1 = start;
   r.This->ull2 = end;
+  r.This->b = prefetchable;
 
   return r;
 }
@@ -1805,10 +1821,14 @@ string resource::asString(const string & separator) const
     case hw::mem:
       result = "memory" + separator;
       snprintf(buffer, sizeof(buffer), "%llx-%llx", This->ull1, This->ull2);
+      if(This->b) strcat(buffer, "(prefetchable)");
       break;
     case hw::ioport:
       result = "ioport" + separator;
-      snprintf(buffer, sizeof(buffer), "%lx-%lx", This->ul1, This->ul2);
+      if(This->ul1 == This->ul2)
+        snprintf(buffer, sizeof(buffer), "%lx", This->ul1);
+      else
+        snprintf(buffer, sizeof(buffer), "%lx(size=%ld)", This->ul1, This->ul2 - This->ul1 + 1);
       break;
     default:
       result = "(unknown)";
@@ -1837,14 +1857,17 @@ const
       return This->ui1 == r.This->ui1;
       break;
 
-    case hw::iomem:case hw::mem:return (This->ull1 >= r.This->ull1)
-      && (This->ull2 <= r.This->ull2) || (r.This->ull1 >= This->ull1)
-      && (r.This->ull2 <= This->ull2);
+    case hw::iomem:
+    case hw::mem:
+      return ((This->ull1 >= r.This->ull1)
+      && (This->ull2 <= r.This->ull2)) || ((r.This->ull1 >= This->ull1)
+      && (r.This->ull2 <= This->ull2));
     break;
 
-    case hw::ioport:return (This->ul1 >= r.This->ul1)
-      && (This->ul1 <= r.This->ul2) || (r.This->ul1 >= This->ul1)
-      && (r.This->ul1 <= This->ul2);
+    case hw::ioport:
+      return ((This->ul1 >= r.This->ul1)
+      && (This->ul1 <= r.This->ul2)) || ((r.This->ul1 >= This->ul1)
+      && (r.This->ul1 <= This->ul2));
     break;
 
     default:return false;
