@@ -52,7 +52,7 @@ namespace hw
 
       static resource iomem(unsigned long long, unsigned long long);
       static resource ioport(unsigned long, unsigned long);
-      static resource mem(unsigned long long, unsigned long long);
+      static resource mem(unsigned long long, unsigned long long, bool prefetchable = false);
       static resource irq(unsigned int);
       static resource dma(unsigned int);
 
@@ -171,6 +171,7 @@ class hwNode
     void addCapability(const string & feature, const string & description = "");
     void describeCapability(const string & feature, const string & description);
     string getCapabilities() const;
+    vector<string> getCapabilitiesList() const;
     string getCapabilityDescription(const string & feature) const;
 
     void attractHandle(const string & handle);
