@@ -19,7 +19,7 @@
 #include <linux/kdev_t.h>
 #endif
 
-__ID("@(#) $Id: osutils.cc 1959 2008-05-09 20:32:50Z lyonel $");
+__ID("@(#) $Id: osutils.cc 2069 2009-02-12 22:53:09Z lyonel $");
 
 using namespace std;
 
@@ -156,6 +156,14 @@ const string & def)
   return result;
 }
 
+long get_number(const string & path, long def)
+{
+  string s = get_string(path, "");
+
+  if(s=="") return def;
+
+  return strtol(s.c_str(), NULL, 10);
+}
 
 int selectdir(const struct dirent *d)
 {
@@ -292,7 +300,7 @@ string get_devid(const string & name)
   {
     char devid[80];
 
-    snprintf(devid, sizeof(devid), "%ud:%ud", (unsigned int)MAJOR(buf.st_rdev), (unsigned int)MINOR(buf.st_rdev));
+    snprintf(devid, sizeof(devid), "%u:%u", (unsigned int)MAJOR(buf.st_rdev), (unsigned int)MINOR(buf.st_rdev));
     return string(devid);
   }
   else
@@ -413,7 +421,6 @@ string spaces(unsigned int count, const string & space)
   return result;
 }
 
-
 string escape(const string & s)
 {
   string result = "";
@@ -440,6 +447,20 @@ string escape(const string & s)
   return result;
 }
 
+string escapecomment(const string & s)
+{
+  string result = "";
+  char previous = 0;
+
+  for (unsigned int i = 0; i < s.length(); i++)
+    if(!(previous == '-' && s[i] == '-'))
+    {
+      result += s[i];
+      previous = s[i];
+    }
+
+  return result;
+}
 
 unsigned short be_short(const void * from)
 {
@@ -514,11 +535,12 @@ unsigned long long le_longlong(const void * from)
 
 int open_dev(dev_t dev, const string & name)
 {
-  static char *paths[] =
+  static const char *paths[] =
   {
     "/usr/tmp", "/var/tmp", "/var/run", "/dev", "/tmp", NULL
   };
-  char **p, fn[64];
+  char const **p;
+  char fn[64];
   int fd;
 
   for (p = paths; *p; p++)
@@ -538,7 +560,7 @@ int open_dev(dev_t dev, const string & name)
   return -1;
 }                                                 /* open_dev */
 
-#define putchar(c) ((char)(c & 0xff))
+#define putchar(c) ((char)((c) & 0xff))
 
 string utf8(wchar_t c)
 {
@@ -551,20 +573,20 @@ string utf8(wchar_t c)
   else if (c < 0x800)
   {
     result += putchar (0xC0 | c>>6);
-    result += putchar (0x80 | c & 0x3F);
+    result += putchar (0x80 | (c & 0x3F));
   }
   else if (c < 0x10000)
   {
     result += putchar (0xE0 | c>>12);
-    result += putchar (0x80 | c>>6 & 0x3F);
-    result += putchar (0x80 | c & 0x3F);
+    result += putchar (0x80 | (c>>6 & 0x3F));
+    result += putchar (0x80 | (c & 0x3F));
   }
   else if (c < 0x200000)
   {
     result += putchar (0xF0 | c>>18);
-    result += putchar (0x80 | c>>12 & 0x3F);
-    result += putchar (0x80 | c>>6 & 0x3F);
-    result += putchar (0x80 | c & 0x3F);
+    result += putchar (0x80 | (c>>12 & 0x3F));
+    result += putchar (0x80 | (c>>6 & 0x3F));
+    result += putchar (0x80 | (c & 0x3F));
   }
 
   return result;
