@@ -10,7 +10,7 @@
 #include <string.h>
 #include <errno.h>
 
-__ID("@(#) $Id: pcmcia-legacy.cc 1959 2008-05-09 20:32:50Z lyonel $");
+__ID("@(#) $Id: pcmcia-legacy.cc 2069 2009-02-12 22:53:09Z lyonel $");
 
 /* parts of this code come from the excellent pcmcia-cs package written by
  * David A. Hinds <dahinds@users.sourceforge.net>.
@@ -844,7 +844,7 @@ ds_ioctl_arg_t;
 
 #define MAX_SOCK 8
 
-static int lookup_dev(char *name)
+static int lookup_dev(const char *name)
 {
   FILE *f;
   int n;
