@@ -21,7 +21,7 @@
 #include <sys/ioctl.h>
 #include <termios.h>
 
-__ID("@(#) $Id: print.cc 1959 2008-05-09 20:32:50Z lyonel $");
+__ID("@(#) $Id: print.cc 2069 2009-02-12 22:53:09Z lyonel $");
 
 static unsigned int columns = 0, rows = 0;
 
@@ -88,20 +88,20 @@ int level)
   if (html && (level == 0))
   {
     cout <<
-      "<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">" <<
+      "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"\n    \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">" <<
       endl;
-    cout << "<html>" << endl;
+    cout << "<html xmlns=\"http://www.w3.org/1999/xhtml\">" << endl;
     cout << "<head>" << endl;
     cout << "<meta name=\"generator\" " <<
-      " content=\"lshw-" << getpackageversion() << "\">" << endl;
+      " content=\"lshw-" << getpackageversion() << "\" />" << endl;
     cout << "<style type=\"text/css\">" << endl;
     cout << "  .first {font-weight: bold; margin-left: none; padding-right: 1em;vertical-align: top; }" << endl;
     cout << "  .second {padding-left: 1em; width: 100%; vertical-align: center; }" << endl;
     cout << "  .id {font-family: monospace;}" << endl;
     cout << "  .indented {margin-left: 2em; border-left: dotted thin #dde; padding-bottom: 1em; }" << endl;
     cout << "  .node {border: solid thin #ffcc66; padding: 1em; background: #ffffcc; }" << endl;
-    cout << "  .node-unclaimed {border: dotted thin #c3c3c3; padding: 1em; background: #fafafa; }" << endl;
-    cout << "  .node-disabled {border: solid thin #f55; padding: 1em; background: #fee; }" << endl;
+    cout << "  .node-unclaimed {border: dotted thin #c3c3c3; padding: 1em; background: #fafafa; color: red; }" << endl;
+    cout << "  .node-disabled {border: solid thin #f55; padding: 1em; background: #fee; color: gray; }" << endl;
     cout << "</style>" << endl;
 
     cout << "<title>";
@@ -133,11 +133,7 @@ int level)
 
     if (html)
       cout << " <thead><tr><td class=\"first\">id:</td><td class=\"second\"><div class=\"id\">";
-    if (html && (!node.claimed() || node.disabled()))
-      cout << "<font color=\"gray\">";
     cout << node.getId();
-    if (html && (!node.claimed() || node.disabled()))
-      cout << "</font>";
     if (html)
       cout << "</div>";
     else
@@ -463,10 +459,17 @@ int level)
         cout << "<tr><td class=\"first\">";
       cout << "capabilities: ";
       if (html)
+      {
+        vector < string > capabilities = node.getCapabilitiesList();
         cout << "</td><td class=\"second\">";
-      cout << node.getCapabilities();
-      if (html)
+        for(unsigned i=0; i<capabilities.size(); i++)
+        {
+          cout << "<dfn title=\"" << escape(node.getCapabilityDescription(capabilities[i])) << "\">" << capabilities[i] << "</dfn> ";
+        }
         cout << "</td></tr>";
+      }
+      else
+        cout << node.getCapabilities();
       cout << endl;
     }
 
