@@ -11,13 +11,14 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <string.h>
 #include <dirent.h>
 #include <libgen.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <sys/mount.h>
 
-__ID("@(#) $Id: sysfs.cc 1907 2007-10-13 22:23:16Z lyonel $");
+__ID("@(#) $Id: sysfs.cc 2069 2009-02-12 22:53:09Z lyonel $");
 
 using namespace sysfs;
 
@@ -293,6 +294,16 @@ entry::~entry()
   delete This;
 }
 
+bool entry::hassubdir(const string & s)
+{
+  if(This->devclass != "")
+    return exists(fs.path + string("/class/") + This->devclass + string("/") + This->devname + "/" + s);
+  
+  if(This->devbus != "")
+    return exists(fs.path + string("/bus/") + This->devbus + string("/devices/") + This->devname + string("/") + s);
+
+  return false;
+}
 
 bool scan_sysfs(hwNode & n)
 {
