@@ -20,7 +20,7 @@
 #include <stdint.h>
 #include <time.h>
 
-__ID("@(#) $Id: volumes.cc 1959 2008-05-09 20:32:50Z lyonel $");
+__ID("@(#) $Id: volumes.cc 2069 2009-02-12 22:53:09Z lyonel $");
 
 struct fstypes
 {
@@ -199,6 +199,7 @@ struct ext2_super_block {
 #define EXT3_FEATURE_INCOMPAT_JOURNAL_DEV       0x0008 /* Journal device */
 #define EXT2_FEATURE_INCOMPAT_META_BG           0x0010
 #define EXT3_FEATURE_INCOMPAT_EXTENTS           0x0040
+#define EXT4_FEATURE_INCOMPAT_EXTENTS           0x0040
 #define EXT4_FEATURE_INCOMPAT_64BIT             0x0080
 #define EXT4_FEATURE_INCOMPAT_MMP               0x0100
 
@@ -295,28 +296,43 @@ static bool detect_ext2(hwNode & n, source & s)
     n.setConfig("lastmountpoint", hw::strip(string(sb->s_last_mounted, sizeof(sb->s_last_mounted))));
     n.setSerial(hw::strip(uuid(sb->s_uuid)));
 
-    if(le_long(&sb->s_feature_compat) && EXT3_FEATURE_COMPAT_HAS_JOURNAL)
+    if(le_long(&sb->s_feature_compat) & EXT3_FEATURE_COMPAT_HAS_JOURNAL)
     {
       n.addCapability("journaled");
       
       mkfstime = (time_t)le_long(&sb->s_mkfs_time);
       n.setConfig("created", datetime(mkfstime));
     }
-    if(le_long(&sb->s_feature_compat) && EXT2_FEATURE_COMPAT_EXT_ATTR)
+    if(le_long(&sb->s_feature_compat) & EXT2_FEATURE_COMPAT_EXT_ATTR)
       n.addCapability("extended_attributes", "Extended Attributes");
-    if(le_long(&sb->s_feature_ro_compat) && EXT2_FEATURE_RO_COMPAT_LARGE_FILE)
+    if(le_long(&sb->s_feature_ro_compat) & EXT2_FEATURE_RO_COMPAT_LARGE_FILE)
       n.addCapability("large_files", "4GB+ files");
-    if(le_long(&sb->s_feature_ro_compat) && EXT4_FEATURE_RO_COMPAT_HUGE_FILE)
+    if(le_long(&sb->s_feature_ro_compat) & EXT4_FEATURE_RO_COMPAT_HUGE_FILE)
       n.addCapability("huge_files", "16TB+ files");
-    if(le_long(&sb->s_feature_incompat) && EXT3_FEATURE_INCOMPAT_RECOVER)
+    if(le_long(&sb->s_feature_ro_compat) & EXT4_FEATURE_RO_COMPAT_DIR_NLINK)
+      n.addCapability("dir_nlink", "directories with 65000+ subdirs");
+    if(le_long(&sb->s_feature_incompat) & EXT3_FEATURE_INCOMPAT_RECOVER)
       n.addCapability("recover", "needs recovery");
+    if(le_long(&sb->s_feature_incompat) & EXT4_FEATURE_INCOMPAT_64BIT)
+      n.addCapability("64bit", "64bit filesystem");
+    if(le_long(&sb->s_feature_incompat) & EXT4_FEATURE_INCOMPAT_EXTENTS)
+      n.addCapability("extents", "extent-based allocation");
   }
 
   if(n.isCapable("journaled"))
   {
-    n.addCapability("ext3");
-    n.setDescription("EXT3 volume");
-    n.setConfig("filesystem", "ext3");
+    if(n.isCapable("huge_files") || n.isCapable("64bit") || n.isCapable("extents") || n.isCapable("dir_nlink"))
+    {
+      n.addCapability("ext4");
+      n.setDescription("EXT4 volume");
+      n.setConfig("filesystem", "ext4");
+    }
+    else
+    {
+      n.addCapability("ext3");
+      n.setDescription("EXT3 volume");
+      n.setConfig("filesystem", "ext3");
+    }
   }
 
   return true;
