@@ -13,17 +13,17 @@
 #include <string.h>
 #include <libgen.h>
 
-static char *id = "@(#) $Id: engine.cc 1959 2008-05-09 20:32:50Z lyonel $";
+static const char *id = "@(#) $Id: engine.cc 2069 2009-02-12 22:53:09Z lyonel $";
 
 extern "C"
 {
 #include "support.h"
 };
 
-#define AUTOMATIC "automatic"
-#define LSHW_XML "lshw XML format"
-#define PLAIN_TEXT "plain text document"
-#define HTML "HTML document"
+#define AUTOMATIC "automatic file format"
+#define LSHW_XML "lshw XML format (.lshw,.xml)"
+#define PLAIN_TEXT "plain text document (.text, .txt)"
+#define HTML "HTML document (.html, .htm)"
 
 #define YIELD()  while(gtk_events_pending()) gtk_main_iteration()
 
@@ -442,7 +442,7 @@ static const char *guess_format(char *s)
   return LSHW_XML;
 }
 
-static char *fix_filename(char *s, char *extension)
+static char *fix_filename(char *s, const char *extension)
 {
   char *dot = strrchr(s, '.');
 
